@@ -346,12 +346,19 @@ tm_tdm_interface <- function(text.var, grouping.var, stopwords, char2space,
     LST <- sapply(split(DF[, "text.var"], DF[, "grouping"]), 
         paste, collapse = " ")
 
-    LST_DF <- qdapTools::list2df(LST, "text.var", "grouping")
+    # LST_DF <- qdapTools::list2df(LST, "text.var", "grouping")
+    # 
+    # ## Use the tm package to convert to a Corpus
+    # mycorpus <- tm::VCorpus(tm::DataframeSource(LST_DF), 
+    #     readerControl=list(reader=qdap_tm_reader))
+    
+    LST_DF <- qdapTools::list2df(LST, "text.var", "id")
+    
+    # ## Use the tm package to convert to a Corpus
+    # mycorpus <- tm::VCorpus(tm::DataframeSource(LST_DF), 
+    #     readerControl=list(reader=qdap_tm_reader))
+    mycorpus <- replace_ids(tm::Corpus(tm::DataframeSource(LST_DF)), LST_DF[['id']])
     
-    ## Use the tm package to convert to a Corpus
-    mycorpus <- tm::VCorpus(tm::DataframeSource(LST_DF), 
-        readerControl=list(reader=qdap_tm_reader))
- 
     ## Add metadata info
     NLP::meta(mycorpus, "MetaID") <- names(LST)
     NLP::meta(mycorpus, "labels") <- names(LST)
